eqcorrscan.core.subspace.Detector
=================================

.. currentmodule:: eqcorrscan.core.subspace

.. autoclass:: Detector

   .. rubric:: Methods

   .. autosummary::

      construct
      detect
      energy_capture
      partition
      plot
      read
      write


   .. automethod:: __init__
   .. automethod:: construct
   .. automethod:: detect
   .. automethod:: energy_capture
   .. automethod:: partition
   .. automethod:: plot
   .. automethod:: read
   .. automethod:: write

